param(
     [Parameter()]
     [string]$appId
 )

 #omit wait to return immedidately, else set wait (in seconds) to set the max time to wait for the reload to finish
 #return codes 0 - successful, 4 - time out, 8 - failed

 #call from Qlik Sense Client-Managed using external tasks in QMC
 #example:
 #path >> c:\windows\system32\windowspowershell\v1.0\powershell.exe
 #parameters >> -File "C:\Users\Qlik\Desktop\QlikMigrationPlaybook\reloadfromwindows.ps1" -appId 72addd30-7a5d-41b7-97b9-0a48fed5535e 

#set the working directory for the Migration Playbook
cd "C:\Users\Qlik\Desktop\QlikMigrationPlaybook"

$ts = Get-Date -Format "yyyy_MM_dd_HH_mm_ss"
Start-Transcript -Path ".\Logs\reload_$ts.txt"

Write-Host "reloading app id: $appId"

. .\0_globals.ps1

.\qlik context use $QlikSaaSContext

$reloadId = .\qlik reload create --appId $appId -q
Write-Host $appId
Write-Host $reloadId

$wait = 600
$start = Get-Date
$elapsed = 0


$status = .\qlik reload get $reloadId | ConvertFrom-Json
$status = $status.status
Write-Host $status

while(($elapsed -lt $wait) -and (($status -eq "RELOADING") -or ($status -eq "CREATED") -or ($status -eq "QUEUED")))
{
    #do not check too frequently or you will get rate limited
    Start-Sleep -s 30
    
    $status = .\qlik reload get $reloadId | ConvertFrom-Json
    $status = $status.status
    Write-Host $status

    $curr = Get-Date
    $elapsed = $curr - $start
    $elapsed = $elapsed.Seconds
}

if($status -eq "SUCCEEDED")
{
    Write-Host("Reload Success")
    exit 0
}
elseif($status -eq "FAILED")
{
    Write-Host("Reload Failed")
    exit 8
}
elseif($elapsed > $wait)
{
    Write-Host("Exceeded Wait Time")
    exit 4
}
else
{
    Write-Host("Something Else Happened")
    exit 8
}

Stop-Transcript
